//
// The goal of this example is to provide a minimal standalone
// program that creates an inverted index and searches in it.
// It is by no mean a tutorial but is commented to allow a fast
// introduction to mifluz.
//
// Compilation:
// gcc -I/usr/local/include/mifluz -L/usr/local/lib -lmifluz example0.cc
//

#include <stdlib.h>

#include <htconfig.h>
#include <WordContext.h>
#include <WordList.h>
#include <Configuration.h>


static ConfigDefaults defaults[] = {
  //
  // Very simple key structure: word+one numerical field
  //
  { "wordlist_wordkey_description","Word/Location 32"},
  { 0 }
};

static Configuration	config;

int main(void) {
  //
  // Mandatory to create global data needed for the library.
  //
  WordContext::Initialize(defaults);

  //
  // Open a new inverted index (O_RDWR), reseting it
  // to empty if it was not empty (O_TRUNC).
  //
  WordList words(config);
  words.Open("words.db", O_RDWR|O_TRUNC);

  //
  // Object holding an entry in the inverted index (key + record).
  //
  WordReference wordRef;

  //
  // For this example we're only interested in the key.
  // Note the reference, when the key variable is modified
  // the key part of the wordRef object is modified.
  //
  WordKey& key = wordRef.Key();

  //
  // Initialize the key from the ascii description of an inverted
  // index entry.
  //
  key.Set("computer <DEF> 0");

  //
  // The WordReference object now holds data that we want to
  // save in the inverted index. The Insert metho ensure that
  // two identical keys are not inserted in the index (no
  // duplicates allowed).
  //
  words.Insert(wordRef);

  //
  // And we push some more words in the index, same story.
  //
  key.Set("computing <DEF> 16");
  words.Insert(wordRef);
  key.Set("computing <DEF> 0");
  words.Insert(wordRef);
  key.Set("hello <DEF> 20");
  words.Insert(wordRef);

  //
  // We now search for all the words that start with 'comput'
  //
  List *results = words.Prefix("comput");
  //
  // And display them
  //
  WordReference *match;
  for(results->Start_Get(); (match = (WordReference*)results->Get_Next());) {
    printf("%s\n", (char*)match->Get());
  }

  //
  // It's not so much important to release the file descriptor
  // than to flush the cached information.
  //
  words.Close();

  printf("Success\n");
}

