//
// mifluz.h
//
// NAME
//   C++ library to use and manage inverted indexes
//
// SYNOPSIS
// #include <mifluz.h>
// 
// main()
// {
//    Configuration* config = WordContext::Initialize();
// 
//    WordList* words = new WordList(*config);
// 
//    ...
// 
//    delete words;
// 
//    WordContext::Finish();
// }
//
// DESCRIPTION
//
// The purpose of mifluz is to provide a C++ library to build and query a
// full text inverted index. It is dynamically updatable, scalable (up to
// 1Tb indexes), uses a controlled amount of memory, shares index files
// and memory cache among processes or threads and compresses index files
// to 50% of the raw data. The structure of the index is configurable at
// runtime and allows inclusion of relevance ranking information. The
// query functions do not require loading all the occurrences of a
// searched term.  They consume very few resources and many searches can
// be run in parallel.
//
// The file management library used in mifluz is a modified Berkeley DB 
// (www.sleepycat.com) version 3.0.55. 
// 
// ENVIRONMENT
//
// <b>MIFLUZ_CONFIG</b> file name of configuration file read by
// WordContext(3). Defaults to <b>~/.mifluz.</b>
//
// END
//
// Part of the ht://Dig package   <http://www.htdig.org/>
// Copyright (c) 1999, 2000 The ht://Dig Group
// For copyright details, see the file COPYING in your distribution
// or the GNU General Public License version 2 or later
// <http://www.gnu.org/copyleft/gpl.html>
//
// $Id: mifluz.h,v 1.8 2000/05/03 04:31:06 loic Exp $
//

#ifndef _mifluz_h_
#define _mifluz_h_

#include <mifluz/htconfig.h>
#include <mifluz/WordContext.h>
#include <mifluz/WordList.h>

#endif /* _mifluz_h */
